[coreboot] v2/src romfs->cbfs rename

Peter Stuge peter at stuge.se
Tue Apr 14 02:38:04 CEST 2009


I expect r4110 to break things because the util was renamed.
This should lead to working builds again.

 src/arch/i386/Config.lb                                       |    4 
 src/boot/Config.lb                                            |    2 
 src/boot/hardwaremain.c                                       |    8 
 src/boot/selfboot.c                                           |   24 +-
 src/config/Options.lb                                         |    4 
 src/devices/pci_rom.c                                         |    6 
 src/include/cbfs.h                                            |   54 ++---
 src/lib/Config.lb                                             |    4 
 src/lib/cbfs.c                                                |  104 +++++-----
 src/mainboard/a-trend/atc-6220/Options.lb                     |    6 
 src/mainboard/a-trend/atc-6240/Options.lb                     |    6 
 src/mainboard/abit/be6-ii_v2_0/Options.lb                     |    6 
 src/mainboard/advantech/pcm-5820/Options.lb                   |    6 
 src/mainboard/amd/db800/Options.lb                            |    6 
 src/mainboard/amd/dbm690t/Options.lb                          |    6 
 src/mainboard/amd/norwich/Options.lb                          |    6 
 src/mainboard/amd/pistachio/Options.lb                        |    6 
 src/mainboard/amd/rumba/Options.lb                            |    6 
 src/mainboard/amd/serengeti_cheetah/Options.lb                |    6 
 src/mainboard/amd/serengeti_cheetah_fam10/Options.lb          |    6 
 src/mainboard/arima/hdama/Options.lb                          |    6 
 src/mainboard/artecgroup/dbe61/Options.lb                     |    6 
 src/mainboard/asi/mb_5blgp/Options.lb                         |    6 
 src/mainboard/asi/mb_5blmp/Options.lb                         |    6 
 src/mainboard/asus/a8n_e/Options.lb                           |    6 
 src/mainboard/asus/a8v-e_se/Options.lb                        |    6 
 src/mainboard/asus/m2v-mx_se/Options.lb                       |    6 
 src/mainboard/asus/mew-am/Options.lb                          |    6 
 src/mainboard/asus/mew-vm/Options.lb                          |    6 
 src/mainboard/asus/p2b-ds/Options.lb                          |    6 
 src/mainboard/asus/p2b-f/Options.lb                           |    6 
 src/mainboard/asus/p2b/Options.lb                             |    6 
 src/mainboard/asus/p3b-f/Options.lb                           |    6 
 src/mainboard/axus/tc320/Options.lb                           |    6 
 src/mainboard/azza/pt-6ibd/Options.lb                         |    6 
 src/mainboard/bcom/winnet100/Options.lb                       |    6 
 src/mainboard/bcom/winnetp680/Options.lb                      |    6 
 src/mainboard/biostar/m6tba/Options.lb                        |    6 
 src/mainboard/broadcom/blast/Options.lb                       |    6 
 src/mainboard/compaq/deskpro_en_sff_p600/Options.lb           |    6 
 src/mainboard/dell/s1850/Options.lb                           |    6 
 src/mainboard/digitallogic/adl855pc/Options.lb                |    6 
 src/mainboard/digitallogic/msm586seg/Options.lb               |    6 
 src/mainboard/digitallogic/msm800sev/Options.lb               |    6 
 src/mainboard/eaglelion/5bcm/Options.lb                       |    6 
 src/mainboard/embeddedplanet/ep405pc/Options.lb               |    6 
 src/mainboard/emulation/qemu-x86/Options.lb                   |    4 
 src/mainboard/gigabyte/ga-6bxc/Options.lb                     |    6 
 src/mainboard/gigabyte/ga_2761gxdk/Options.lb                 |    6 
 src/mainboard/gigabyte/m57sli/Options.lb                      |    6 
 src/mainboard/ibm/e325/Options.lb                             |    6 
 src/mainboard/ibm/e326/Options.lb                             |    6 
 src/mainboard/iei/juki-511p/Options.lb                        |    6 
 src/mainboard/iei/nova4899r/Options.lb                        |    6 
 src/mainboard/iei/pcisa-lx-800-r10/Options.lb                 |    6 
 src/mainboard/intel/jarrell/Options.lb                        |    6 
 src/mainboard/intel/mtarvon/Options.lb                        |    6 
 src/mainboard/intel/truxton/Options.lb                        |    6 
 src/mainboard/intel/xe7501devkit/Options.lb                   |    6 
 src/mainboard/iwill/dk8_htx/Options.lb                        |    6 
 src/mainboard/iwill/dk8s2/Options.lb                          |    6 
 src/mainboard/iwill/dk8x/Options.lb                           |    6 
 src/mainboard/jetway/j7f24/Options.lb                         |    6 
 src/mainboard/kontron/986lcd-m/Options.lb                     |    6 
 src/mainboard/lippert/frontrunner/Options.lb                  |    6 
 src/mainboard/lippert/roadrunner-lx/Options.lb                |    6 
 src/mainboard/lippert/spacerunner-lx/Options.lb               |    6 
 src/mainboard/motorola/sandpoint/Options.lb                   |    6 
 src/mainboard/motorola/sandpointx3_altimus_mpc7410/Options.lb |    6 
 src/mainboard/msi/ms6119/Options.lb                           |    6 
 src/mainboard/msi/ms6147/Options.lb                           |    6 
 src/mainboard/msi/ms6178/Options.lb                           |    6 
 src/mainboard/msi/ms7135/Options.lb                           |    6 
 src/mainboard/msi/ms7260/Options.lb                           |    6 
 src/mainboard/msi/ms9185/Options.lb                           |    6 
 src/mainboard/msi/ms9282/Options.lb                           |    6 
 src/mainboard/nec/powermate2000/Options.lb                    |    6 
 src/mainboard/newisys/khepri/Options.lb                       |    6 
 src/mainboard/nvidia/l1_2pvv/Options.lb                       |    6 
 src/mainboard/olpc/btest/Options.lb                           |    6 
 src/mainboard/olpc/rev_a/Options.lb                           |    6 
 src/mainboard/pcengines/alix1c/Options.lb                     |    6 
 src/mainboard/rca/rm4100/Options.lb                           |    6 
 src/mainboard/sunw/ultra40/Options.lb                         |    6 
 src/mainboard/supermicro/h8dme/Options.lb                     |    6 
 src/mainboard/supermicro/h8dmr/Options.lb                     |    6 
 src/mainboard/supermicro/x6dai_g/Options.lb                   |    6 
 src/mainboard/supermicro/x6dhe_g/Options.lb                   |    6 
 src/mainboard/supermicro/x6dhe_g2/Options.lb                  |    6 
 src/mainboard/supermicro/x6dhr_ig/Options.lb                  |    6 
 src/mainboard/supermicro/x6dhr_ig2/Options.lb                 |    6 
 src/mainboard/technexion/tim8690/Options.lb                   |    2 
 src/mainboard/technologic/ts5300/Options.lb                   |    6 
 src/mainboard/televideo/tc7020/Options.lb                     |    6 
 src/mainboard/thomson/ip1000/Options.lb                       |    6 
 src/mainboard/totalimpact/briq/Options.lb                     |    6 
 src/mainboard/tyan/s1846/Options.lb                           |    6 
 src/mainboard/tyan/s2735/Options.lb                           |    6 
 src/mainboard/tyan/s2850/Options.lb                           |    6 
 src/mainboard/tyan/s2875/Options.lb                           |    6 
 src/mainboard/tyan/s2880/Options.lb                           |    6 
 src/mainboard/tyan/s2881/Options.lb                           |    6 
 src/mainboard/tyan/s2882/Options.lb                           |    6 
 src/mainboard/tyan/s2885/Options.lb                           |    6 
 src/mainboard/tyan/s2891/Options.lb                           |    6 
 src/mainboard/tyan/s2892/Options.lb                           |    6 
 src/mainboard/tyan/s2895/Options.lb                           |    6 
 src/mainboard/tyan/s2912/Options.lb                           |    6 
 src/mainboard/tyan/s2912_fam10/Options.lb                     |    6 
 src/mainboard/tyan/s4880/Options.lb                           |    6 
 src/mainboard/tyan/s4882/Options.lb                           |    6 
 src/mainboard/via/epia-cn/Options.lb                          |    8 
 src/mainboard/via/epia-m/Options.lb                           |    6 
 src/mainboard/via/epia/Options.lb                             |    6 
 src/mainboard/via/pc2500e/Options.lb                          |    6 
 util/newconfig/config.g                                       |   20 -
 116 files changed, 431 insertions(+), 431 deletions(-)


//Peter
-------------- next part --------------
v2/src: romfs->cbfs rename

This also has the changes in the config tool.

Rename romfs.[ch]->cbfs.[ch] and sed romfs->cbfs romtool->cbfstool ROMFS->CBFS

Signed-off-by: Peter Stuge <peter at stuge.se>

Index: util/newconfig/config.g
===================================================================
--- util/newconfig/config.g	(revision 4109)
+++ util/newconfig/config.g	(working copy)
@@ -2224,11 +2224,11 @@
 	file = safe_open(makefilepath, 'w+')
 	writemakefileheader(file, makefilepath)
 
-	# Hack to get the necessary settings (CONFIG_ROMFS):
+	# Hack to get the necessary settings (CONFIG_CBFS):
 	file.write("include %s/Makefile.settings\n\n" % romimages.keys()[0])
 
 	# main rule
-	file.write("ifeq \"$(CONFIG_ROMFS)\" \"1\"\n")
+	file.write("ifeq \"$(CONFIG_CBFS)\" \"1\"\n")
 	file.write("\nall: ")
 	for i in buildroms:
 		file.write(" %sfs" % i.name)
@@ -2240,8 +2240,8 @@
 	file.write("\n")
 	file.write("endif\n\n")
 
-	# romtool rules
-	file.write("\nromtool:\n\tmkdir -p tools/lzma\n\t$(MAKE) -C $(TOP)/util/romtool obj=$(shell pwd)\n\n")
+	# cbfstool rules
+	file.write("\ncbfstool:\n\tmkdir -p tools/lzma\n\t$(MAKE) -C $(TOP)/util/cbfstool obj=$(shell pwd)\n\n")
 
 	file.write("include Makefile.settings\n\n")
 	for i, o in romimages.items():
@@ -2278,17 +2278,17 @@
 
 	romsize = getoption("ROM_SIZE", image)
 	# i.name? That can not be right, can it? 
-	file.write("%sfs: %s romtool\n" %(i.name,i.name));
-	file.write("\trm -f coreboot.romfs\n");
-	file.write("\t./romtool %sfs create %s %s %s.bootblock\n" % (i.name, romsize, bootblocksize, i.name))
+	file.write("%sfs: %s cbfstool\n" %(i.name,i.name));
+	file.write("\trm -f coreboot.cbfs\n");
+	file.write("\t./cbfstool %sfs create %s %s %s.bootblock\n" % (i.name, romsize, bootblocksize, i.name))
 	for i in buildroms:
 		for j in i.roms:
 			#failover is a hack that will go away soon. 
 			if (j != "failover") and (rommapping[j] != "/dev/null"):
-				file.write("\tif [ -f %s/romfs-support ]; then ./romtool %sfs add-payload %s %s/payload `cat %s/romfs-support`; fi\n" % (j, i.name, rommapping[j], j, j))
-		file.write("\t ./romtool %sfs print\n" % i.name)
+				file.write("\tif [ -f %s/cbfs-support ]; then ./cbfstool %sfs add-payload %s %s/payload `cat %s/cbfs-support`; fi\n" % (j, i.name, rommapping[j], j, j))
+		file.write("\t ./cbfstool %sfs print\n" % i.name)
 
-	file.write(".PHONY: all clean romtool")
+	file.write(".PHONY: all clean cbfstool")
 	for i in romimages.keys():
 		file.write(" %s-clean" % i)
 	for i, o in romimages.items():
Index: src/boot/hardwaremain.c
===================================================================
--- src/boot/hardwaremain.c	(revision 4109)
+++ src/boot/hardwaremain.c	(working copy)
@@ -36,7 +36,7 @@
 #include <part/hard_reset.h>
 #include <part/init_timer.h>
 #include <boot/elf.h>
-#include <romfs.h>
+#include <cbfs.h>
 #include <arch/acpi.h>
 
 /**
@@ -110,11 +110,11 @@
 	 * write our configuration tables.
 	 */
 	lb_mem = write_tables();
-#if CONFIG_ROMFS == 1
+#if CONFIG_CBFS == 1
 # if USE_FALLBACK_IMAGE == 1
-	void (*pl)(void) = romfs_load_payload(lb_mem, "fallback/payload");
+	void (*pl)(void) = cbfs_load_payload(lb_mem, "fallback/payload");
 # else
-	void (*pl)(void) = romfs_load_payload(lb_mem, "normal/payload");
+	void (*pl)(void) = cbfs_load_payload(lb_mem, "normal/payload");
 # endif
 #endif
 
Index: src/boot/Config.lb
===================================================================
--- src/boot/Config.lb	(revision 4109)
+++ src/boot/Config.lb	(working copy)
@@ -1,6 +1,6 @@
 object elfboot.o
 object hardwaremain.o
-if CONFIG_ROMFS
+if CONFIG_CBFS
 	object selfboot.o
 end
 if CONFIG_FS_PAYLOAD
Index: src/boot/selfboot.c
===================================================================
--- src/boot/selfboot.c	(revision 4109)
+++ src/boot/selfboot.c	(working copy)
@@ -28,7 +28,7 @@
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <romfs.h>
+#include <cbfs.h>
 
 #ifndef CONFIG_BIG_ENDIAN
 #define ntohl(x) ( ((x&0xff)<<24) | ((x&0xff00)<<8) | \
@@ -70,12 +70,12 @@
 	unsigned short ip_checksum;
 };
 
-int romfs_self_decompress(int algo, void *src,struct segment *new)
+int cbfs_self_decompress(int algo, void *src,struct segment *new)
 {
 	u8 *dst;
 
 	/* for uncompressed, it's easy: just point at the area in ROM */
-	if (algo ==  ROMFS_COMPRESS_NONE) {
+	if (algo ==  CBFS_COMPRESS_NONE) {
 		new->s_srcaddr = (u32) src;
 		new->s_filesz =  new->s_memsz;
 		return 0;
@@ -91,21 +91,21 @@
 
 	switch(algo) {
 #ifdef CONFIG_COMPRESSION_LZMA
-	case ROMFS_COMPRESS_LZMA: {
+	case CBFS_COMPRESS_LZMA: {
 		unsigned long ulzma(unsigned char *src, unsigned char *dst);		
 		ulzma(src, dst);
 	}
 #endif
 
 #ifdef CONFIG_COMPRESSION_NRV2B
-	case ROMFS_COMPRESS_NRV2B: {
+	case CBFS_COMPRESS_NRV2B: {
 		unsigned long unrv2b(u8 *src, u8 *dst, unsigned long *ilen_p);
 		unsigned long tmp;
 		unrv2b(src, dst, &tmp);
 	}
 #endif
 	default:
-		printk_info( "ROMFS:  Unknown compression type %d\n",
+		printk_info( "CBFS:  Unknown compression type %d\n",
 		       algo);
 		return -1;
 	}
@@ -341,13 +341,13 @@
 static int build_self_segment_list(
 	struct segment *head, 
 	unsigned long bounce_buffer, struct lb_memory *mem,
-	struct romfs_payload *payload, u32 *entry)
+	struct cbfs_payload *payload, u32 *entry)
 {
 	struct segment *new;
 	struct segment *ptr;
 	u8 *data;
 	int datasize;
-	struct romfs_payload_segment *segment, *first_segment;
+	struct cbfs_payload_segment *segment, *first_segment;
 	memset(head, 0, sizeof(*head));
 	head->phdr_next = head->phdr_prev = head;
 	head->next = head->prev = head;
@@ -372,10 +372,10 @@
 
 		datasize = ntohl(segment->len);
 		/* figure out decompression, do it, get pointer to the area */
-		if (romfs_self_decompress(ntohl(segment->compression),
+		if (cbfs_self_decompress(ntohl(segment->compression),
 					     ((unsigned char *) first_segment) +
 					     ntohl(segment->offset), new)) {
-			printk_emerg("romfs_self_decompress failed\n");
+			printk_emerg("cbfs_self_decompress failed\n");
 			return;
 		}
 		printk_debug("New segment dstaddr 0x%lx memsize 0x%lx srcaddr 0x%lx filesize 0x%lx\n",
@@ -432,7 +432,7 @@
 }
 
 static int load_self_segments(
-	struct segment *head, struct romfs_payload *payload)
+	struct segment *head, struct cbfs_payload *payload)
 {
 	unsigned long offset;
 	struct segment *ptr;
@@ -478,7 +478,7 @@
 	return 0;
 }
 
-int selfboot(struct lb_memory *mem, struct romfs_payload *payload)
+int selfboot(struct lb_memory *mem, struct cbfs_payload *payload)
 {
 	void *entry;
 	struct segment head;
Index: src/arch/i386/Config.lb
===================================================================
--- src/arch/i386/Config.lb	(revision 4109)
+++ src/arch/i386/Config.lb	(working copy)
@@ -80,8 +80,8 @@
 else
 	makerule coreboot.rom 
 		depends	"coreboot.strip buildrom $(PAYLOAD-1)"
-		action "PAYLOAD=$(PAYLOAD-1); if [ $(CONFIG_ROMFS) -eq 1 ]; then PAYLOAD=/dev/null; touch romfs-support; fi; ./buildrom $< $@ $$PAYLOAD $(ROM_IMAGE_SIZE) $(ROM_SECTION_SIZE)"
-		action "if [ $(CONFIG_COMPRESSED_PAYLOAD_LZMA) -eq 1 -a $(CONFIG_ROMFS) -eq 1 ]; then echo l > romfs-support; fi"
+		action "PAYLOAD=$(PAYLOAD-1); if [ $(CONFIG_CBFS) -eq 1 ]; then PAYLOAD=/dev/null; touch cbfs-support; fi; ./buildrom $< $@ $$PAYLOAD $(ROM_IMAGE_SIZE) $(ROM_SECTION_SIZE)"
+		action "if [ $(CONFIG_COMPRESSED_PAYLOAD_LZMA) -eq 1 -a $(CONFIG_CBFS) -eq 1 ]; then echo l > cbfs-support; fi"
 	end
 end
 
Index: src/config/Options.lb
===================================================================
--- src/config/Options.lb	(revision 4109)
+++ src/config/Options.lb	(working copy)
@@ -679,10 +679,10 @@
 	export always
 	comment "Enable FAT filesystem support"
 end
-define CONFIG_ROMFS
+define CONFIG_CBFS
 	default 0
 	export always
-	comment "The new ROMFS file system"
+	comment "The new CBFS file system"
 end
 define AUTOBOOT_DELAY
 	default 2
Index: src/devices/pci_rom.c
===================================================================
--- src/devices/pci_rom.c	(revision 4109)
+++ src/devices/pci_rom.c	(working copy)
@@ -27,7 +27,7 @@
 #include <device/pci_ids.h>
 #include <device/pci_ops.h>
 #include <string.h>
-#include <romfs.h>
+#include <cbfs.h>
 
 struct rom_header * pci_rom_probe(struct device *dev)
 {
@@ -35,10 +35,10 @@
 	struct rom_header *rom_header;
 	struct pci_data *rom_data;
 
-	if (CONFIG_ROMFS) {
+	if (CONFIG_CBFS) {
 		void *v;
 		/* if it's in FLASH, then it's as if dev->on_mainboard was true */
-		v = romfs_load_optionrom(dev->vendor, dev->device, NULL);
+		v = cbfs_load_optionrom(dev->vendor, dev->device, NULL);
 		printk_debug("In cbfs, rom address for %s = %lx\n", 
 				dev_path(dev), rom_address);
 		if (v) {
Index: src/lib/Config.lb
===================================================================
--- src/lib/Config.lb	(revision 4109)
+++ src/lib/Config.lb	(working copy)
@@ -28,6 +28,6 @@
 	initobject memcmp.o
 end
 
-if CONFIG_ROMFS
-	object romfs.o
+if CONFIG_CBFS
+	object cbfs.o
 end
Index: src/mainboard/pcengines/alix1c/Options.lb
===================================================================
--- src/mainboard/pcengines/alix1c/Options.lb	(revision 4109)
+++ src/mainboard/pcengines/alix1c/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -198,8 +198,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/embeddedplanet/ep405pc/Options.lb
===================================================================
--- src/mainboard/embeddedplanet/ep405pc/Options.lb	(revision 4109)
+++ src/mainboard/embeddedplanet/ep405pc/Options.lb	(working copy)
@@ -3,7 +3,7 @@
 ##
 
 uses PCIC0_CFGADDR 
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses PCIC0_CFGDATA 
 uses ISA_IO_BASE 
 uses ISA_MEM_BASE 
@@ -143,8 +143,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/digitallogic/adl855pc/Options.lb
===================================================================
--- src/mainboard/digitallogic/adl855pc/Options.lb	(revision 4109)
+++ src/mainboard/digitallogic/adl855pc/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -116,8 +116,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/digitallogic/msm586seg/Options.lb
===================================================================
--- src/mainboard/digitallogic/msm586seg/Options.lb	(revision 4109)
+++ src/mainboard/digitallogic/msm586seg/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -124,8 +124,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/digitallogic/msm800sev/Options.lb
===================================================================
--- src/mainboard/digitallogic/msm800sev/Options.lb	(revision 4109)
+++ src/mainboard/digitallogic/msm800sev/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -180,8 +180,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/compaq/deskpro_en_sff_p600/Options.lb
===================================================================
--- src/mainboard/compaq/deskpro_en_sff_p600/Options.lb	(revision 4109)
+++ src/mainboard/compaq/deskpro_en_sff_p600/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/p3b-f/Options.lb
===================================================================
--- src/mainboard/asus/p3b-f/Options.lb	(revision 4109)
+++ src/mainboard/asus/p3b-f/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/p2b-f/Options.lb
===================================================================
--- src/mainboard/asus/p2b-f/Options.lb	(revision 4109)
+++ src/mainboard/asus/p2b-f/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/mew-vm/Options.lb
===================================================================
--- src/mainboard/asus/mew-vm/Options.lb	(revision 4109)
+++ src/mainboard/asus/mew-vm/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -159,8 +159,8 @@
 default CONFIG_UDELAY_TSC=1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/m2v-mx_se/Options.lb
===================================================================
--- src/mainboard/asus/m2v-mx_se/Options.lb	(revision 4109)
+++ src/mainboard/asus/m2v-mx_se/Options.lb	(working copy)
@@ -18,7 +18,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -176,8 +176,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 9
 default MAINBOARD_POWER_ON_AFTER_POWER_FAIL = "MAINBOARD_POWER_ON"
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/a8n_e/Options.lb
===================================================================
--- src/mainboard/asus/a8n_e/Options.lb	(revision 4109)
+++ src/mainboard/asus/a8n_e/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses USE_FAILOVER_IMAGE
@@ -168,8 +168,8 @@
 default MAINBOARD_POWER_ON_AFTER_POWER_FAIL = "MAINBOARD_POWER_ON"
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/mew-am/Options.lb
===================================================================
--- src/mainboard/asus/mew-am/Options.lb	(revision 4109)
+++ src/mainboard/asus/mew-am/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1		# Override this in targets/*/Config.lb.
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/p2b-ds/Options.lb
===================================================================
--- src/mainboard/asus/p2b-ds/Options.lb	(revision 4109)
+++ src/mainboard/asus/p2b-ds/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -105,8 +105,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/a8v-e_se/Options.lb
===================================================================
--- src/mainboard/asus/a8v-e_se/Options.lb	(revision 4109)
+++ src/mainboard/asus/a8v-e_se/Options.lb	(working copy)
@@ -18,7 +18,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -168,8 +168,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 8
 default MAINBOARD_POWER_ON_AFTER_POWER_FAIL = "MAINBOARD_POWER_ON"
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asus/p2b/Options.lb
===================================================================
--- src/mainboard/asus/p2b/Options.lb	(revision 4109)
+++ src/mainboard/asus/p2b/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -99,8 +99,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/rca/rm4100/Options.lb
===================================================================
--- src/mainboard/rca/rm4100/Options.lb	(revision 4109)
+++ src/mainboard/rca/rm4100/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses CC
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses CONFIG_CONSOLE_SERIAL8250
 uses CONFIG_CONSOLE_VGA
 uses CONFIG_COMPRESSED_PAYLOAD_LZMA
@@ -95,8 +95,8 @@
 default MAINBOARD_VENDOR = "RCA"
 default MAINBOARD_PART_NUMBER = "RM4100"
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/olpc/btest/Options.lb
===================================================================
--- src/mainboard/olpc/btest/Options.lb	(revision 4109)
+++ src/mainboard/olpc/btest/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -162,8 +162,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/olpc/rev_a/Options.lb
===================================================================
--- src/mainboard/olpc/rev_a/Options.lb	(revision 4109)
+++ src/mainboard/olpc/rev_a/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -162,8 +162,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/axus/tc320/Options.lb
===================================================================
--- src/mainboard/axus/tc320/Options.lb	(revision 4109)
+++ src/mainboard/axus/tc320/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -104,8 +104,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 6
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/thomson/ip1000/Options.lb
===================================================================
--- src/mainboard/thomson/ip1000/Options.lb	(revision 4109)
+++ src/mainboard/thomson/ip1000/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses CC
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses CONFIG_CONSOLE_SERIAL8250
 uses CONFIG_CONSOLE_VGA
 uses CONFIG_COMPRESSED_PAYLOAD_LZMA
@@ -95,8 +95,8 @@
 default MAINBOARD_VENDOR = "THOMSON"
 default MAINBOARD_PART_NUMBER = "IP1000"
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/ibm/e325/Options.lb
===================================================================
--- src/mainboard/ibm/e325/Options.lb	(revision 4109)
+++ src/mainboard/ibm/e325/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -222,8 +222,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/ibm/e326/Options.lb
===================================================================
--- src/mainboard/ibm/e326/Options.lb	(revision 4109)
+++ src/mainboard/ibm/e326/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -228,8 +228,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asi/mb_5blmp/Options.lb
===================================================================
--- src/mainboard/asi/mb_5blmp/Options.lb	(revision 4109)
+++ src/mainboard/asi/mb_5blmp/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_PIRQ_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
 uses HAVE_HARD_RESET
@@ -163,8 +163,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/asi/mb_5blgp/Options.lb
===================================================================
--- src/mainboard/asi/mb_5blgp/Options.lb	(revision 4109)
+++ src/mainboard/asi/mb_5blgp/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -104,8 +104,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 9
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/broadcom/blast/Options.lb
===================================================================
--- src/mainboard/broadcom/blast/Options.lb	(revision 4109)
+++ src/mainboard/broadcom/blast/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -263,8 +263,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/nec/powermate2000/Options.lb
===================================================================
--- src/mainboard/nec/powermate2000/Options.lb	(revision 4109)
+++ src/mainboard/nec/powermate2000/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -97,8 +97,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/via/epia/Options.lb
===================================================================
--- src/mainboard/via/epia/Options.lb	(revision 4109)
+++ src/mainboard/via/epia/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses MAXIMUM_CONSOLE_LOGLEVEL
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses DEFAULT_CONSOLE_LOGLEVEL
 uses CONFIG_CONSOLE_SERIAL8250
 uses TTYS0_BAUD
@@ -143,8 +143,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/via/pc2500e/Options.lb
===================================================================
--- src/mainboard/via/pc2500e/Options.lb	(revision 4109)
+++ src/mainboard/via/pc2500e/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses CONFIG_SMP
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_MP_TABLE
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
@@ -114,8 +114,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/via/epia-m/Options.lb
===================================================================
--- src/mainboard/via/epia-m/Options.lb	(revision 4109)
+++ src/mainboard/via/epia-m/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -145,8 +145,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/via/epia-cn/Options.lb
===================================================================
--- src/mainboard/via/epia-cn/Options.lb	(revision 4109)
+++ src/mainboard/via/epia-cn/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -82,7 +82,7 @@
 default HAVE_HARD_RESET = 0
 default HAVE_PIRQ_TABLE = 1
 default IRQ_SLOT_COUNT = 9
-default HAVE_ACPI_TABLES = 0
+default HAVE_ACPI_TABLES = 1
 default HAVE_OPTION_TABLE = 1
 default ROM_IMAGE_SIZE = 64 * 1024
 default FALLBACK_SIZE = ROM_SIZE
@@ -106,8 +106,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/azza/pt-6ibd/Options.lb
===================================================================
--- src/mainboard/azza/pt-6ibd/Options.lb	(revision 4109)
+++ src/mainboard/azza/pt-6ibd/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/iei/pcisa-lx-800-r10/Options.lb
===================================================================
--- src/mainboard/iei/pcisa-lx-800-r10/Options.lb	(revision 4109)
+++ src/mainboard/iei/pcisa-lx-800-r10/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -106,8 +106,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/iei/juki-511p/Options.lb
===================================================================
--- src/mainboard/iei/juki-511p/Options.lb	(revision 4109)
+++ src/mainboard/iei/juki-511p/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -147,8 +147,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/iei/nova4899r/Options.lb
===================================================================
--- src/mainboard/iei/nova4899r/Options.lb	(revision 4109)
+++ src/mainboard/iei/nova4899r/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -174,8 +174,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/dbm690t/Options.lb
===================================================================
--- src/mainboard/amd/dbm690t/Options.lb	(revision 4109)
+++ src/mainboard/amd/dbm690t/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -302,8 +302,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/pistachio/Options.lb
===================================================================
--- src/mainboard/amd/pistachio/Options.lb	(revision 4109)
+++ src/mainboard/amd/pistachio/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -302,8 +302,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/db800/Options.lb
===================================================================
--- src/mainboard/amd/db800/Options.lb	(revision 4109)
+++ src/mainboard/amd/db800/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -180,8 +180,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/serengeti_cheetah_fam10/Options.lb
===================================================================
--- src/mainboard/amd/serengeti_cheetah_fam10/Options.lb	(revision 4109)
+++ src/mainboard/amd/serengeti_cheetah_fam10/Options.lb	(working copy)
@@ -18,7 +18,7 @@
 #
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -365,8 +365,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/rumba/Options.lb
===================================================================
--- src/mainboard/amd/rumba/Options.lb	(revision 4109)
+++ src/mainboard/amd/rumba/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -161,8 +161,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/serengeti_cheetah/Options.lb
===================================================================
--- src/mainboard/amd/serengeti_cheetah/Options.lb	(revision 4109)
+++ src/mainboard/amd/serengeti_cheetah/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -330,8 +330,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/amd/norwich/Options.lb
===================================================================
--- src/mainboard/amd/norwich/Options.lb	(revision 4109)
+++ src/mainboard/amd/norwich/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -180,8 +180,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/televideo/tc7020/Options.lb
===================================================================
--- src/mainboard/televideo/tc7020/Options.lb	(revision 4109)
+++ src/mainboard/televideo/tc7020/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -105,8 +105,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 6
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/nvidia/l1_2pvv/Options.lb
===================================================================
--- src/mainboard/nvidia/l1_2pvv/Options.lb	(revision 4109)
+++ src/mainboard/nvidia/l1_2pvv/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -352,8 +352,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/emulation/qemu-x86/Options.lb
===================================================================
--- src/mainboard/emulation/qemu-x86/Options.lb	(revision 4109)
+++ src/mainboard/emulation/qemu-x86/Options.lb	(working copy)
@@ -44,13 +44,13 @@
 
 uses DEFAULT_CONSOLE_LOGLEVEL
 uses MAXIMUM_CONSOLE_LOGLEVEL
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 
 
 default CONFIG_CONSOLE_SERIAL8250=1
 default DEFAULT_CONSOLE_LOGLEVEL=8
 default MAXIMUM_CONSOLE_LOGLEVEL=8
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 
 ## ROM_SIZE is the size of boot ROM that this board will use.
 default ROM_SIZE  = 256*1024
Index: src/mainboard/abit/be6-ii_v2_0/Options.lb
===================================================================
--- src/mainboard/abit/be6-ii_v2_0/Options.lb	(revision 4109)
+++ src/mainboard/abit/be6-ii_v2_0/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -99,8 +99,8 @@
 default CONFIG_PCI_ROM_RUN = 1		# Override this in targets/*/Config.lb.
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/biostar/m6tba/Options.lb
===================================================================
--- src/mainboard/biostar/m6tba/Options.lb	(revision 4109)
+++ src/mainboard/biostar/m6tba/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/advantech/pcm-5820/Options.lb
===================================================================
--- src/mainboard/advantech/pcm-5820/Options.lb	(revision 4109)
+++ src/mainboard/advantech/pcm-5820/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -104,8 +104,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 9
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/dell/s1850/Options.lb
===================================================================
--- src/mainboard/dell/s1850/Options.lb	(revision 4109)
+++ src/mainboard/dell/s1850/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -229,8 +229,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2850/Options.lb
===================================================================
--- src/mainboard/tyan/s2850/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2850/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -247,8 +247,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2735/Options.lb
===================================================================
--- src/mainboard/tyan/s2735/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2735/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -256,8 +256,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s4882/Options.lb
===================================================================
--- src/mainboard/tyan/s4882/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s4882/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -255,8 +255,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2891/Options.lb
===================================================================
--- src/mainboard/tyan/s2891/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2891/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -307,8 +307,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s1846/Options.lb
===================================================================
--- src/mainboard/tyan/s1846/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s1846/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -99,8 +99,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s4880/Options.lb
===================================================================
--- src/mainboard/tyan/s4880/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s4880/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -256,8 +256,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2882/Options.lb
===================================================================
--- src/mainboard/tyan/s2882/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2882/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -247,8 +247,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2885/Options.lb
===================================================================
--- src/mainboard/tyan/s2885/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2885/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -274,8 +274,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2875/Options.lb
===================================================================
--- src/mainboard/tyan/s2875/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2875/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -248,8 +248,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2912/Options.lb
===================================================================
--- src/mainboard/tyan/s2912/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2912/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -354,8 +354,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2895/Options.lb
===================================================================
--- src/mainboard/tyan/s2895/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2895/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -314,8 +314,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2912_fam10/Options.lb
===================================================================
--- src/mainboard/tyan/s2912_fam10/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2912_fam10/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -362,8 +362,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2892/Options.lb
===================================================================
--- src/mainboard/tyan/s2892/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2892/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -295,8 +295,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2880/Options.lb
===================================================================
--- src/mainboard/tyan/s2880/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2880/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -247,8 +247,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/tyan/s2881/Options.lb
===================================================================
--- src/mainboard/tyan/s2881/Options.lb	(revision 4109)
+++ src/mainboard/tyan/s2881/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -264,8 +264,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/x6dai_g/Options.lb
===================================================================
--- src/mainboard/supermicro/x6dai_g/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/x6dai_g/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -230,8 +230,8 @@
 ### End Options.lb
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/h8dme/Options.lb
===================================================================
--- src/mainboard/supermicro/h8dme/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/h8dme/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ## 
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -349,8 +349,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/x6dhr_ig/Options.lb
===================================================================
--- src/mainboard/supermicro/x6dhr_ig/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/x6dhr_ig/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -229,8 +229,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/h8dmr/Options.lb
===================================================================
--- src/mainboard/supermicro/h8dmr/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/h8dmr/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ## 
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -349,8 +349,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/x6dhr_ig2/Options.lb
===================================================================
--- src/mainboard/supermicro/x6dhr_ig2/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/x6dhr_ig2/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -229,8 +229,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/x6dhe_g/Options.lb
===================================================================
--- src/mainboard/supermicro/x6dhe_g/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/x6dhe_g/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -230,8 +230,8 @@
 ### End Options.lb
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/supermicro/x6dhe_g2/Options.lb
===================================================================
--- src/mainboard/supermicro/x6dhe_g2/Options.lb	(revision 4109)
+++ src/mainboard/supermicro/x6dhe_g2/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -230,8 +230,8 @@
 ### End Options.lb
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/gigabyte/m57sli/Options.lb
===================================================================
--- src/mainboard/gigabyte/m57sli/Options.lb	(revision 4109)
+++ src/mainboard/gigabyte/m57sli/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ## 
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -358,8 +358,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/gigabyte/ga_2761gxdk/Options.lb
===================================================================
--- src/mainboard/gigabyte/ga_2761gxdk/Options.lb	(revision 4109)
+++ src/mainboard/gigabyte/ga_2761gxdk/Options.lb	(working copy)
@@ -22,7 +22,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -354,8 +354,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/gigabyte/ga-6bxc/Options.lb
===================================================================
--- src/mainboard/gigabyte/ga-6bxc/Options.lb	(revision 4109)
+++ src/mainboard/gigabyte/ga-6bxc/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/technologic/ts5300/Options.lb
===================================================================
--- src/mainboard/technologic/ts5300/Options.lb	(revision 4109)
+++ src/mainboard/technologic/ts5300/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -137,8 +137,8 @@
 default HOSTCC="gcc"
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/sunw/ultra40/Options.lb
===================================================================
--- src/mainboard/sunw/ultra40/Options.lb	(revision 4109)
+++ src/mainboard/sunw/ultra40/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -279,8 +279,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/bcom/winnetp680/Options.lb
===================================================================
--- src/mainboard/bcom/winnetp680/Options.lb	(revision 4109)
+++ src/mainboard/bcom/winnetp680/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -105,8 +105,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/bcom/winnet100/Options.lb
===================================================================
--- src/mainboard/bcom/winnet100/Options.lb	(revision 4109)
+++ src/mainboard/bcom/winnet100/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -104,8 +104,8 @@
 default MAXIMUM_CONSOLE_LOGLEVEL = 6
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/kontron/986lcd-m/Options.lb
===================================================================
--- src/mainboard/kontron/986lcd-m/Options.lb	(revision 4109)
+++ src/mainboard/kontron/986lcd-m/Options.lb	(working copy)
@@ -72,7 +72,7 @@
 uses MMCONF_SUPPORT
 uses MMCONF_BASE_ADDRESS
 uses CONFIG_GFXUMA
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 
 #
 uses MAINBOARD
@@ -325,9 +325,9 @@
 default MAINBOARD_POWER_ON_AFTER_POWER_FAIL="MAINBOARD_POWER_ON"
 
 #
-# ROMFS
+# CBFS
 # 
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 
 ### End Options.lb
 end
Index: src/mainboard/msi/ms7260/Options.lb
===================================================================
--- src/mainboard/msi/ms7260/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms7260/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses USE_FAILOVER_IMAGE
@@ -187,8 +187,8 @@
 default MAINBOARD_POWER_ON_AFTER_POWER_FAIL = "MAINBOARD_POWER_ON"
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/msi/ms9185/Options.lb
===================================================================
--- src/mainboard/msi/ms9185/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms9185/Options.lb	(working copy)
@@ -23,7 +23,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -331,8 +331,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/msi/ms6119/Options.lb
===================================================================
--- src/mainboard/msi/ms6119/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms6119/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/msi/ms9282/Options.lb
===================================================================
--- src/mainboard/msi/ms9282/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms9282/Options.lb	(working copy)
@@ -23,7 +23,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -310,8 +310,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/msi/ms6147/Options.lb
===================================================================
--- src/mainboard/msi/ms6147/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms6147/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/msi/ms7135/Options.lb
===================================================================
--- src/mainboard/msi/ms7135/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms7135/Options.lb	(working copy)
@@ -21,7 +21,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses USE_FAILOVER_IMAGE
@@ -322,8 +322,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/msi/ms6178/Options.lb
===================================================================
--- src/mainboard/msi/ms6178/Options.lb	(revision 4109)
+++ src/mainboard/msi/ms6178/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -97,8 +97,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/arima/hdama/Options.lb
===================================================================
--- src/mainboard/arima/hdama/Options.lb	(revision 4109)
+++ src/mainboard/arima/hdama/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -243,8 +243,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/iwill/dk8x/Options.lb
===================================================================
--- src/mainboard/iwill/dk8x/Options.lb	(revision 4109)
+++ src/mainboard/iwill/dk8x/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -228,8 +228,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/iwill/dk8s2/Options.lb
===================================================================
--- src/mainboard/iwill/dk8s2/Options.lb	(revision 4109)
+++ src/mainboard/iwill/dk8s2/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -229,8 +229,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/iwill/dk8_htx/Options.lb
===================================================================
--- src/mainboard/iwill/dk8_htx/Options.lb	(revision 4109)
+++ src/mainboard/iwill/dk8_htx/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
@@ -329,8 +329,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/totalimpact/briq/Options.lb
===================================================================
--- src/mainboard/totalimpact/briq/Options.lb	(revision 4109)
+++ src/mainboard/totalimpact/briq/Options.lb	(working copy)
@@ -3,7 +3,7 @@
 ##
 
 uses TTYS0_DIV
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses TTYS0_BASE
 uses CONFIG_BRIQ_750FX
 uses CONFIG_BRIQ_7400
@@ -127,8 +127,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/lippert/spacerunner-lx/Options.lb
===================================================================
--- src/mainboard/lippert/spacerunner-lx/Options.lb	(revision 4109)
+++ src/mainboard/lippert/spacerunner-lx/Options.lb	(working copy)
@@ -21,7 +21,7 @@
 ## Based on Options.lb from AMD's DB800 mainboard.
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -210,8 +210,8 @@
 default  MAXIMUM_CONSOLE_LOGLEVEL = 8
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/lippert/roadrunner-lx/Options.lb
===================================================================
--- src/mainboard/lippert/roadrunner-lx/Options.lb	(revision 4109)
+++ src/mainboard/lippert/roadrunner-lx/Options.lb	(working copy)
@@ -21,7 +21,7 @@
 ## Based on Options.lb from AMD's DB800 mainboard.
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -210,8 +210,8 @@
 default  MAXIMUM_CONSOLE_LOGLEVEL = 8
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/lippert/frontrunner/Options.lb
===================================================================
--- src/mainboard/lippert/frontrunner/Options.lb	(revision 4109)
+++ src/mainboard/lippert/frontrunner/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -161,8 +161,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/intel/xe7501devkit/Options.lb
===================================================================
--- src/mainboard/intel/xe7501devkit/Options.lb	(revision 4109)
+++ src/mainboard/intel/xe7501devkit/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
 uses HAVE_PIRQ_TABLE
@@ -241,8 +241,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/intel/mtarvon/Options.lb
===================================================================
--- src/mainboard/intel/mtarvon/Options.lb	(revision 4109)
+++ src/mainboard/intel/mtarvon/Options.lb	(working copy)
@@ -18,7 +18,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -226,8 +226,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/intel/jarrell/Options.lb
===================================================================
--- src/mainboard/intel/jarrell/Options.lb	(revision 4109)
+++ src/mainboard/intel/jarrell/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -243,8 +243,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/intel/truxton/Options.lb
===================================================================
--- src/mainboard/intel/truxton/Options.lb	(revision 4109)
+++ src/mainboard/intel/truxton/Options.lb	(working copy)
@@ -18,7 +18,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -228,8 +228,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/a-trend/atc-6220/Options.lb
===================================================================
--- src/mainboard/a-trend/atc-6220/Options.lb	(revision 4109)
+++ src/mainboard/a-trend/atc-6220/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/a-trend/atc-6240/Options.lb
===================================================================
--- src/mainboard/a-trend/atc-6240/Options.lb	(revision 4109)
+++ src/mainboard/a-trend/atc-6240/Options.lb	(working copy)
@@ -19,7 +19,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -98,8 +98,8 @@
 default CONFIG_PCI_ROM_RUN = 1
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/technexion/tim8690/Options.lb
===================================================================
--- src/mainboard/technexion/tim8690/Options.lb	(revision 4109)
+++ src/mainboard/technexion/tim8690/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses HAVE_ACPI_TABLES
 uses HAVE_ACPI_RESUME
Index: src/mainboard/artecgroup/dbe61/Options.lb
===================================================================
--- src/mainboard/artecgroup/dbe61/Options.lb	(revision 4109)
+++ src/mainboard/artecgroup/dbe61/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -180,8 +180,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/eaglelion/5bcm/Options.lb
===================================================================
--- src/mainboard/eaglelion/5bcm/Options.lb	(revision 4109)
+++ src/mainboard/eaglelion/5bcm/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -166,8 +166,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/motorola/sandpoint/Options.lb
===================================================================
--- src/mainboard/motorola/sandpoint/Options.lb	(revision 4109)
+++ src/mainboard/motorola/sandpoint/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses CONFIG_SANDPOINT_ALTIMUS
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses CONFIG_SANDPOINT_TALUS
 uses CONFIG_SANDPOINT_UNITY
 uses CONFIG_SANDPOINT_VALIS
@@ -125,8 +125,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/motorola/sandpointx3_altimus_mpc7410/Options.lb
===================================================================
--- src/mainboard/motorola/sandpointx3_altimus_mpc7410/Options.lb	(revision 4109)
+++ src/mainboard/motorola/sandpointx3_altimus_mpc7410/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses ISA_IO_BASE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses ISA_MEM_BASE
 uses PCIC0_CFGADDR
 uses PCIC0_CFGDATA
@@ -120,8 +120,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/newisys/khepri/Options.lb
===================================================================
--- src/mainboard/newisys/khepri/Options.lb	(revision 4109)
+++ src/mainboard/newisys/khepri/Options.lb	(working copy)
@@ -1,5 +1,5 @@
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -246,8 +246,8 @@
 
 ### End Options.lb
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end
Index: src/mainboard/jetway/j7f24/Options.lb
===================================================================
--- src/mainboard/jetway/j7f24/Options.lb	(revision 4109)
+++ src/mainboard/jetway/j7f24/Options.lb	(working copy)
@@ -20,7 +20,7 @@
 ##
 
 uses HAVE_MP_TABLE
-uses CONFIG_ROMFS
+uses CONFIG_CBFS
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
 uses HAVE_FALLBACK_BOOT
@@ -106,8 +106,8 @@
 
 
 #
-# ROMFS
+# CBFS
 #
 #
-default CONFIG_ROMFS=0
+default CONFIG_CBFS=0
 end


More information about the coreboot mailing list
Index: src/include/cbfs.h
===================================================================
--- src/include/cbfs.h	(revision 4109)
+++ src/include/cbfs.h	(working copy)
@@ -46,38 +46,38 @@
  * ---------------------------------------------------------------------------
  */
 
-#ifndef _ROMFS_H_
-#define _ROMFS_H_
+#ifndef _CBFS_H_
+#define _CBFS_H_
 
 /** These are standard values for the known compression
     alogrithms that coreboot knows about for stages and
     payloads.  Of course, other LAR users can use whatever
     values they want, as long as they understand them. */
 
-#define ROMFS_COMPRESS_NONE  0
-#define ROMFS_COMPRESS_LZMA  1
-#define ROMFS_COMPRESS_NRV2B 2
+#define CBFS_COMPRESS_NONE  0
+#define CBFS_COMPRESS_LZMA  1
+#define CBFS_COMPRESS_NRV2B 2
 
 /** These are standard component types for well known
     components (i.e - those that coreboot needs to consume.
     Users are welcome to use any other value for their
     components */
 
-#define ROMFS_TYPE_STAGE     0x10
-#define ROMFS_TYPE_PAYLOAD   0x20
-#define ROMFS_TYPE_OPTIONROM 0x30
+#define CBFS_TYPE_STAGE     0x10
+#define CBFS_TYPE_PAYLOAD   0x20
+#define CBFS_TYPE_OPTIONROM 0x30
 
 /** this is the master romfs header - it need to be
     located somewhere in the bootblock.  Where it
     actually lives is up to coreboot. A pointer to
     this header will live at 0xFFFFFFFc, so we can
     easily find it. */
 
-#define ROMFS_HEADER_MAGIC  0x4F524243
-#define ROMFS_HEADPTR_ADDR 0xFFFFFFFc
+#define CBFS_HEADER_MAGIC  0x4F524243
+#define CBFS_HEADPTR_ADDR 0xFFFFFFFc
 #define VERSION1 0x31313131
 
-struct romfs_header {
+struct cbfs_header {
 	u32 magic;
         u32 version; 
         u32 romsize;
@@ -87,7 +87,7 @@
 	u32 pad[2];
 } __attribute__((packed));
 
 /** This is a component header - every entry in the ROMFS
     will have this header.
 
     This is how the component is arranged in the ROM:
@@ -102,9 +102,9 @@
     --------------   <- offset + len
 */
 
-#define ROMFS_FILE_MAGIC "LARCHIVE"
+#define CBFS_FILE_MAGIC "LARCHIVE"
 
-struct romfs_file {
+struct cbfs_file {
 	char magic[8];
 	u32 len;
 	u32 type;
@@ -120,7 +120,7 @@
 /** This is the sub-header for stage components.  Stages are
     loaded by coreboot during the normal boot process */
 
-struct romfs_stage {
+struct cbfs_stage {
 	u32 compression;  /** Compression type */
 	u64 entry;  /** entry point */
 	u64 load;   /** Where to load in memory */
@@ -131,7 +131,7 @@
 /** this is the sub-header for payload components.  Payloads
     are loaded by coreboot at the end of the boot process */
 
-struct romfs_payload_segment {
+struct cbfs_payload_segment {
 	u32 type;
 	u32 compression;
 	u32 offset;
@@ -140,8 +140,8 @@
 	u32 mem_len;
 } __attribute__((packed));
 
-struct romfs_payload {
-	struct romfs_payload_segment segments;
+struct cbfs_payload {
+	struct cbfs_payload_segment segments;
 };
 
 #define PAYLOAD_SEGMENT_CODE   0x45444F43
@@ -150,19 +150,19 @@
 #define PAYLOAD_SEGMENT_PARAMS 0x41524150
 #define PAYLOAD_SEGMENT_ENTRY  0x52544E45
 
-struct romfs_optionrom {
+struct cbfs_optionrom {
 	u32 compression;
 	u32 len;
 } __attribute__((packed));
 
-#define ROMFS_NAME(_c) (((char *) (_c)) + sizeof(struct romfs_file))
-#define ROMFS_SUBHEADER(_p) ( (void *) ((((u8 *) (_p)) + ntohl((_p)->offset))) )
+#define CBFS_NAME(_c) (((char *) (_c)) + sizeof(struct cbfs_file))
+#define CBFS_SUBHEADER(_p) ( (void *) ((((u8 *) (_p)) + ntohl((_p)->offset))) )
 
-void * romfs_load_payload(struct lb_memory *lb_mem, const char *name);
-void * romfs_load_stage(const char *name);
-int romfs_execute_stage(const char *name);
-void * romfs_get_file(const char *name);
-void *romfs_load_optionrom(u16 vendor, u16 device, void * dest);
+void * cbfs_load_payload(struct lb_memory *lb_mem, const char *name);
+void * cbfs_load_stage(const char *name);
+int cbfs_execute_stage(const char *name);
+void * cbfs_get_file(const char *name);
+void *cbfs_load_optionrom(u16 vendor, u16 device, void * dest);
 int run_address(void *f);
 
 #endif
@@ -46,38 +46,38 @@
 
-/** this is the master romfs header - it need to be
+/** this is the master cbfs header - it need to be
     located somewhere in the bootblock.  Where it
     actually lives is up to coreboot. A pointer to
@@ -87,7 +87,7 @@
 } __attribute__((packed));
 
-/** This is a component header - every entry in the ROMFS
+/** This is a component header - every entry in the CBFS
     will have this header.
 
Index: src/lib/cbfs.c
===================================================================
--- src/lib/cbfs.c	(revision 4109)
+++ src/lib/cbfs.c	(working copy)
@@ -21,7 +21,7 @@
 #include <string.h>
 #include <console/console.h>
 #include <boot/coreboot_tables.h>
-#include <romfs.h>
+#include <cbfs.h>
 
 #ifndef CONFIG_BIG_ENDIAN
 #define ntohl(x) ( ((x&0xff)<<24) | ((x&0xff00)<<8) | \
@@ -32,16 +32,16 @@
 
 int run_address(void *f);
 
-int romfs_decompress(int algo, void *src, void *dst, int len)
+int cbfs_decompress(int algo, void *src, void *dst, int len)
 {
 	switch(algo) {
-	case ROMFS_COMPRESS_NONE:
+	case CBFS_COMPRESS_NONE:
 		memcpy(dst, src, len);
 		return 0;
 
 #ifdef CONFIG_COMPRESSION_LZMA
 
-	case ROMFS_COMPRESS_LZMA: {
+	case CBFS_COMPRESS_LZMA: {
 		unsigned long ulzma(unsigned char *src, unsigned char *dst);
 		ulzma(src, dst);
 	}
@@ -49,7 +49,7 @@
 #endif
 
 #ifdef CONFIG_COMPRESSION_NRV2B
-	case ROMFS_COMPRESS_NRV2B: {
+	case CBFS_COMPRESS_NRV2B: {
 		unsigned long unrv2b(u8 *src, u8 *dst, unsigned long *ilen_p);
 		unsigned long tmp;
 
@@ -58,38 +58,38 @@
 		return 0;
 #endif
 	default:
-		printk_info( "ROMFS:  Unknown compression type %d\n",
+		printk_info( "CBFS:  Unknown compression type %d\n",
 		       algo);
 		return -1;
 	}
 }
 
-int romfs_check_magic(struct romfs_file *file)
+int cbfs_check_magic(struct cbfs_file *file)
 {
-	return !strcmp(file->magic, ROMFS_FILE_MAGIC) ? 1 : 0;
+	return !strcmp(file->magic, CBFS_FILE_MAGIC) ? 1 : 0;
 }
 
-struct romfs_header *romfs_master_header(void)
+struct cbfs_header *cbfs_master_header(void)
 {
-	struct romfs_header *header;
+	struct cbfs_header *header;
 
-	void *ptr = (void *)*((unsigned long *) ROMFS_HEADPTR_ADDR);
-	printk_debug("Check ROMFS header at %p\n", ptr);
-	header = (struct romfs_header *) ptr;
+	void *ptr = (void *)*((unsigned long *) CBFS_HEADPTR_ADDR);
+	printk_debug("Check CBFS header at %p\n", ptr);
+	header = (struct cbfs_header *) ptr;
 
 	printk_debug("magic is %08x\n", ntohl(header->magic));
-	if (ntohl(header->magic) != ROMFS_HEADER_MAGIC) {
-		printk_err("NO ROMFS HEADER\n");
+	if (ntohl(header->magic) != CBFS_HEADER_MAGIC) {
+		printk_err("NO CBFS HEADER\n");
 		return NULL;
 	}
 
-	printk_debug("Found ROMFS header at %p\n", ptr);
+	printk_debug("Found CBFS header at %p\n", ptr);
 	return header;
 }
 
-struct romfs_file *romfs_find(const char *name)
+struct cbfs_file *cbfs_find(const char *name)
 {
-	struct romfs_header *header = romfs_master_header();
+	struct cbfs_header *header = cbfs_master_header();
 	unsigned long offset;
 
 	if (header == NULL)
@@ -97,10 +97,10 @@
 	offset = 0 - ntohl(header->romsize) + ntohl(header->offset);
 
 	while(1) {
-		struct romfs_file *file = (struct romfs_file *) offset;
-		if (romfs_check_magic(file)) printk_info("Check %s\n", ROMFS_NAME(file));
-		if (romfs_check_magic(file) &&
-		    !strcmp(ROMFS_NAME(file), name))
+		struct cbfs_file *file = (struct cbfs_file *) offset;
+		if (cbfs_check_magic(file)) printk_info("Check %s\n", CBFS_NAME(file));
+		if (cbfs_check_magic(file) &&
+		    !strcmp(CBFS_NAME(file), name))
 			return file;
 
 		offset += ntohl(header->align);
@@ -110,36 +110,36 @@
 	}
 }
 
-struct romfs_stage *romfs_find_file(const char *name, int type)
+struct cbfs_stage *cbfs_find_file(const char *name, int type)
 {
-	struct romfs_file *file = romfs_find(name);
+	struct cbfs_file *file = cbfs_find(name);
 
 	if (file == NULL) {
-		printk_info( "ROMFS:  Could not find file %s\n",
+		printk_info( "CBFS:  Could not find file %s\n",
 		       name);
 		return NULL;
 	}
 
 	if (ntohl(file->type) != type) {
-		printk_info( "ROMFS:  File %s is of type %x instead of"
+		printk_info( "CBFS:  File %s is of type %x instead of"
 		       "type %x\n", name, file->type, type);
 
 		return NULL;
 	}
 
-	return (void *) ROMFS_SUBHEADER(file);
+	return (void *) CBFS_SUBHEADER(file);
 }
 
-void *romfs_load_optionrom(u16 vendor, u16 device, void * dest)
+void *cbfs_load_optionrom(u16 vendor, u16 device, void * dest)
 {
 	char name[17];
-	struct romfs_optionrom *orom;
+	struct cbfs_optionrom *orom;
 	u8 *src;
 
 	sprintf(name,"pci%04x,%04x.rom", vendor, device);
 
-	orom = (struct romfs_optionrom *)
-		romfs_find_file(name, ROMFS_TYPE_OPTIONROM);
+	orom = (struct cbfs_optionrom *)
+		cbfs_find_file(name, CBFS_TYPE_OPTIONROM);
 
 	if (orom == NULL)
 		return NULL;
@@ -151,13 +151,13 @@
 	 * return a pointer to it. 
  	 */
 
-	/* BUG: the romtool is (not yet) including a romfs_optionrom header */
-	src = ((unsigned char *) orom); // + sizeof(struct romfs_optionrom);
+	/* BUG: the cbfstool is (not yet) including a cbfs_optionrom header */
+	src = ((unsigned char *) orom); // + sizeof(struct cbfs_optionrom);
 
 	if (! dest)
 		return src;
 
-	if (romfs_decompress(ntohl(orom->compression),
+	if (cbfs_decompress(ntohl(orom->compression),
 			     src,
 			     dest,
 			     ntohl(orom->len)))
@@ -166,13 +166,13 @@
 	return dest;
 }
 
-void * romfs_load_payload(struct lb_memory *lb_mem, const char *name)
+void * cbfs_load_payload(struct lb_memory *lb_mem, const char *name)
 {
-	int selfboot(struct lb_memory *mem, struct romfs_payload *payload);
-	struct romfs_payload *payload = (struct romfs_payload *)
-		romfs_find_file(name, ROMFS_TYPE_PAYLOAD);
+	int selfboot(struct lb_memory *mem, struct cbfs_payload *payload);
+	struct cbfs_payload *payload = (struct cbfs_payload *)
+		cbfs_find_file(name, CBFS_TYPE_PAYLOAD);
 
-	struct romfs_payload_segment *segment, *first_segment;
+	struct cbfs_payload_segment *segment, *first_segment;
 
 	if (payload == NULL)
 		return (void *) -1;
@@ -184,10 +184,10 @@
 	return (void *) -1;
 }
 
-void * romfs_load_stage(const char *name)
+void * cbfs_load_stage(const char *name)
 {
-	struct romfs_stage *stage = (struct romfs_stage *)
-		romfs_find_file(name, ROMFS_TYPE_STAGE);
+	struct cbfs_stage *stage = (struct cbfs_stage *)
+		cbfs_find_file(name, CBFS_TYPE_STAGE);
 	/* this is a mess. There is no ntohll. */
 	/* for now, assume compatible byte order until we solve this. */
 	u32 entry;
@@ -200,9 +200,9 @@
 			stage->entry);
 	memset((void *) ntohl((u32) stage->load), 0, ntohl(stage->memlen));
 
-	if (romfs_decompress(ntohl(stage->compression),
+	if (cbfs_decompress(ntohl(stage->compression),
 			     ((unsigned char *) stage) +
-			     sizeof(struct romfs_stage),
+			     sizeof(struct cbfs_stage),
 			     (void *) ntohl((u32) stage->load),
 			     ntohl(stage->len)))
 		return (void *) -1;
@@ -212,27 +212,27 @@
 	return (void *) entry;
 }
 
-void * romfs_get_file(const char *name)
+void * cbfs_get_file(const char *name)
 {
-	return romfs_find(name);
+	return cbfs_find(name);
 }
 
-int romfs_execute_stage(const char *name)
+int cbfs_execute_stage(const char *name)
 {
-	struct romfs_stage *stage = (struct romfs_stage *)
-		romfs_find_file(name, ROMFS_TYPE_STAGE);
+	struct cbfs_stage *stage = (struct cbfs_stage *)
+		cbfs_find_file(name, CBFS_TYPE_STAGE);
 
 	if (stage == NULL)
 		return 1;
 
-	if (ntohl(stage->compression) != ROMFS_COMPRESS_NONE) {
-		printk_info( "ROMFS:  Unable to run %s:  Compressed file"
+	if (ntohl(stage->compression) != CBFS_COMPRESS_NONE) {
+		printk_info( "CBFS:  Unable to run %s:  Compressed file"
 		       "Not supported for in-place execution\n", name);
 		return 1;
 	}
 
 	/* FIXME: This isn't right */
-	printk_info( "ROMFS: run @ %p\n", (void *) ntohl((u32) stage->entry));
+	printk_info( "CBFS: run @ %p\n", (void *) ntohl((u32) stage->entry));
 	return run_address((void *) ntohl((u32) stage->entry));
 }
 